@@ -23,12 +23,9 @@ from .tm import (
     ms,
     us,
     ns,
-    ms_to_ts,
-    us_to_ts,
-    ns_to_ts,
     to_sec,
     is_timestamp,
 )
 
-__version__ = '0.1.3'
-_name = 'k3time'
+__version__ = '0.1.5'
+__name__ = 'k3time'
